@@ -1,5 +1,5 @@
 
-INVALID_HANDLE_VALUE = 0
+INVALID_HANDLE_VALUE = -1
 
 ERROR_NO_MORE_ITEMS = 259
 ERROR_MORE_DATA = 234
